@@ -5,19 +5,25 @@ FAILSTATUS=""
 check_pkg() {
 	pkgname=$1
 	add_define=$2
-	pkgconfig_args=$3
+	atleast_version=$3
 	echo -n "Checking for package ${pkgname}... "
 	if pkg-config --silence-errors "${pkgname}" ; then
 		echo "found"
+		if [ -n "$atleast_version" ] ; then
+			if ! pkg-config --atleast-version=$atleast_version ${pkgname} ; then
+				echo "at least ${pkgname} $atleast_version required."
+				exit 1
+			fi
+		fi
 		echo "# configuration for package ${pkgname}" >> config.mk
-		result=`pkg-config --cflags $pkgconfig_args ${pkgname}`
+		result=`pkg-config --cflags ${pkgname}`
 		if [ -n "$result" ] ; then
 			echo "DEFINES+=$result" >> config.mk
 		fi
 		if [ -n "$add_define" ] ; then
 			echo "DEFINES+=${add_define}" >> config.mk
 		fi
-		echo "LDFLAGS+=`pkg-config --libs $pkgconfig_args ${pkgname}`" >> config.mk
+		echo "LDFLAGS+=`pkg-config --libs ${pkgname}`" >> config.mk
 		echo "" >> config.mk
 	else
 		echo "not found"
@@ -99,12 +105,12 @@ check_pkg "sqlite3" || fail "sqlite3"
 check_pkg "libcurl" || check_custom "libcurl" "curl-config" || fail "libcurl"
 check_pkg "libxml-2.0" || check_custom "libxml2" "xml2-config" || fail "libxml2"
 check_pkg "stfl" || fail "stfl"
-( check_pkg "json" || check_pkg "json-c" ) || fail "json-c"
+( check_pkg "json" "" 0.11 || check_pkg "json-c" "" 0.11 ) || fail "json-c"
 
 if [ `uname -s` = "Darwin" ]; then
 	check_custom "ncurses5.4" "ncurses5.4-config" || fail "ncurses5.4"
-else 
-	check_custom "ncursesw5" "ncursesw5-config" || fail "ncursesw5"
+elif [ `uname -s` != "OpenBSD" ]; then
+	check_custom "ncursesw5" "ncursesw5-config" ||  fail "ncursesw"
 fi
 check_ssl_implementation
 all_aboard_the_fail_boat
