@@ -47,6 +47,7 @@ namespace newsbeuter {
 			void handle_itunes_summary(std::tr1::shared_ptr<rss_item> x, rsspp::item& item);
 			bool is_html_type(const std::string& type);
 			void fetch_ttrss(const std::string& feed_id);
+			void fetch_newsblur(const std::string& feed_id);
 
 			std::string my_uri;
 			cache * ch;
@@ -57,6 +58,7 @@ namespace newsbeuter {
 			rsspp::feed f;
 			remote_api * api;
 			bool is_ttrss;
+			bool is_newsblur;
 
 			curl_handle *easyhandle;
 	};
