@@ -64,7 +64,7 @@ configcontainer::configcontainer()
 	config_data["notify-program"]  = configdata("", configdata::PATH);
 	config_data["notify-format"]   = configdata(_("newsbeuter: finished reload, %f unread feeds (%n unread articles total)"), configdata::STR);
 	config_data["datetime-format"] = configdata("%b %d", configdata::STR);
-	config_data["urls-source"]     = configdata("local", "local", "opml", "googlereader", "ttrss", NULL); // enum
+	config_data["urls-source"]     = configdata("local", "local", "opml", "oldreader", "ttrss", "newsblur", NULL); // enum
 	config_data["bookmark-cmd"]    = configdata("", configdata::STR);
 	config_data["opml-url"]        = configdata("", configdata::STR, true);
 	config_data["html-renderer"]   = configdata("internal", configdata::PATH);
@@ -93,13 +93,13 @@ configcontainer::configcontainer()
 	config_data["prepopulate-query-feeds"] = configdata("false", configdata::BOOL);
 	config_data["goto-first-unread"] = configdata("true", configdata::BOOL);
 	config_data["proxy-type"] = configdata("http", "http", "socks4", "socks4a", "socks5", NULL); // enum
-	config_data["googlereader-login"] = configdata("", configdata::STR);
-	config_data["googlereader-password"] = configdata("", configdata::STR);
-	config_data["googlereader-passwordfile"] = configdata("", configdata::PATH);
-	config_data["googlereader-flag-share"] = configdata("", configdata::STR);
-	config_data["googlereader-flag-star"] = configdata("", configdata::STR);
-	config_data["googlereader-show-special-feeds"] = configdata("true", configdata::BOOL);
-	config_data["googlereader-min-items"] = configdata("20", configdata::INT);
+	config_data["oldreader-login"] = configdata("", configdata::STR);
+	config_data["oldreader-password"] = configdata("", configdata::STR);
+	config_data["oldreader-passwordfile"] = configdata("", configdata::PATH);
+	config_data["oldreader-flag-share"] = configdata("", configdata::STR);
+	config_data["oldreader-flag-star"] = configdata("", configdata::STR);
+	config_data["oldreader-show-special-feeds"] = configdata("true", configdata::BOOL);
+	config_data["oldreader-min-items"] = configdata("20", configdata::INT);
 	config_data["ignore-mode"] = configdata("download", "download", "display", NULL); // enum
 	config_data["max-download-speed"] = configdata("0", configdata::INT);
 	config_data["cookie-cache"] = configdata("", configdata::STR);
@@ -107,10 +107,15 @@ configcontainer::configcontainer()
 	config_data["external-url-viewer"] = configdata("", configdata::STR);
 	config_data["ttrss-login"] = configdata("", configdata::STR);
 	config_data["ttrss-password"] = configdata("", configdata::STR);
+	config_data["ttrss-passwordfile"] = configdata("", configdata::PATH);
 	config_data["ttrss-url"] = configdata("", configdata::STR);
 	config_data["ttrss-mode"] = configdata("multi", "single", "multi", NULL); // enum
 	config_data["ttrss-flag-star"] = configdata("", configdata::STR);
 	config_data["ttrss-flag-publish"] = configdata("", configdata::STR);
+	config_data["newsblur-login"] = configdata("", configdata::STR);
+	config_data["newsblur-password"] = configdata("", configdata::STR);
+	config_data["newsblur-url"] = configdata("https://newsblur.com", configdata::STR);
+	config_data["newsblur-min-items"] = configdata("20", configdata::INT);
 	config_data["delete-read-articles-on-quit"] = configdata("false", configdata::BOOL);
 	config_data["openbrowser-and-mark-jumps-to-next-unread"] = configdata("false", configdata::BOOL);
 	config_data["toggleitemread-jumps-to-next-unread"] = configdata("false", configdata::BOOL);
