@@ -14,8 +14,9 @@
 #include <regexmanager.h>
 #include <rss_parser.h>
 #include <remote_api.h>
-#include <google_api.h>
+#include <oldreader_api.h>
 #include <ttrss_api.h>
+#include <newsblur_api.h>
 #include <xlicense.h>
 
 #include <cstdlib>
@@ -434,14 +435,18 @@ void controller::run(int argc, char * argv[]) {
 	} else if (type == "opml") {
 		urlcfg = new opml_urlreader(&cfg);
 		real_offline_mode = offline_mode;
-	} else if (type == "googlereader") {
-		api = new googlereader_api(&cfg);
-		urlcfg = new googlereader_urlreader(&cfg, url_file, api);
+	} else if (type == "oldreader") {
+		api = new oldreader_api(&cfg);
+		urlcfg = new oldreader_urlreader(&cfg, url_file, api);
 		real_offline_mode = offline_mode;
 	} else if (type == "ttrss") {
 		api = new ttrss_api(&cfg);
 		urlcfg = new ttrss_urlreader(&cfg, url_file, api);
 		real_offline_mode = offline_mode;
+	} else if (type == "newsblur") {
+		api = new newsblur_api(&cfg);
+		urlcfg = new newsblur_urlreader(&cfg, url_file, api);
+		real_offline_mode = offline_mode;
 	} else {
 		LOG(LOG_ERROR,"unknown urls-source `%s'", urlcfg->get_source().c_str());
 	}
@@ -472,19 +477,6 @@ void controller::run(int argc, char * argv[]) {
 		if (!do_export && !silent) {
 			std::cout << _("done.") << std::endl;
 		}
-		if (api && type == "googlereader") { // ugly hack!
-			std::vector<google_replay_pair> actions = rsscache->get_google_replay();
-			if (!actions.empty()) {
-				std::cout << _("Updating Google Reader unread states...");
-				std::cout.flush();
-
-				std::vector<std::string> successful_guids = dynamic_cast<googlereader_api *>(api)->bulk_mark_articles_read(actions);
-
-				rsscache->delete_google_replay_by_guid(successful_guids);
-
-				std::cout << _("done.") << std::endl;
-			}
-		}
 	}
 
 	if (urlcfg->get_urls().size() == 0) {
@@ -494,10 +486,12 @@ void controller::run(int argc, char * argv[]) {
 			msg = utils::strprintf(_("Error: no URLs configured. Please fill the file %s with RSS feed URLs or import an OPML file."), url_file.c_str());
 		} else if (type == "opml") {
 			msg = utils::strprintf(_("It looks like the OPML feed you subscribed contains no feeds. Please fill it with feeds, and try again."));
-		} else if (type == "googlereader") {
-			msg = utils::strprintf(_("It looks like you haven't configured any feeds in your Google Reader account. Please do so, and try again."));
+		} else if (type == "oldreader") {
+			msg = utils::strprintf(_("It looks like you haven't configured any feeds in your The Old Reader account. Please do so, and try again."));
 		} else if (type == "ttrss") {
 			msg = utils::strprintf(_("It looks like you haven't configured any feeds in your Tiny Tiny RSS account. Please do so, and try again."));
+		} else if (type == "newsblur") {
+			msg = utils::strprintf(_("It looks like you haven't configured any feeds in your NewsBlur account. Please do so, and try again."));
 		} else {
 			assert(0); // shouldn't happen
 		}
@@ -588,10 +582,15 @@ void controller::run(int argc, char * argv[]) {
 		return;
 	}
 
+	// hand over the important objects to the view
+	v->set_config_container(&cfg);
+	v->set_keymap(&keys);
+	v->set_tags(tags);
+
 	if (execute_cmds) {
 		execute_commands(argv, optind);
 		utils::remove_fs_lock(lock_file);
-		return;	
+		return;
 	}
 
 	// if the user wants to refresh on startup via configuration file, then do so,
@@ -600,12 +599,6 @@ void controller::run(int argc, char * argv[]) {
 		refresh_on_start = true;
 	}
 
-	// hand over the important objects to the view
-	v->set_config_container(&cfg);
-	v->set_keymap(&keys);
-	v->set_tags(tags);
-
-
 	formaction::load_histories(searchfile, cmdlinefile);
 
 	// run the view
@@ -669,12 +662,7 @@ void controller::catchup_all() {
 void controller::mark_article_read(const std::string& guid, bool read) {
 	if (api) {
 		if (offline_mode) {
-			if (dynamic_cast<googlereader_api *>(api) != NULL) {
-				LOG(LOG_DEBUG, "controller::mark_article_read: recording %s", guid.c_str());
-				record_google_replay(guid, read);
-			} else {
-				LOG(LOG_DEBUG, "not on googlereader_api");
-			}
+			LOG(LOG_DEBUG, "not on googlereader_api");
 		} else {
 			api->mark_article_read(guid, read);
 		}
@@ -1019,7 +1007,7 @@ void controller::usage(char * argv0) {
 		{ 'C', _("<configfile>"), _("read configuration from <configfile>") },
 		{ 'X', "", _("clean up cache thoroughly") },
 		{ 'x', _("<command>..."), _("execute list of commands") },
-		{ 'o', "", _("activate offline mode (only applies to Google Reader synchronization mode)") },
+		{ 'o', "", _("activate offline mode (only applies to The Old Reader synchronization mode)") },
 		{ 'q', "", _("quiet startup") },
 		{ 'v', "", _("get version information") },
 		{ 'l', _("<loglevel>"), _("write a log with a certain loglevel (valid values: 1 to 6)") },
@@ -1416,12 +1404,7 @@ void controller::save_feed(std::tr1::shared_ptr<rss_feed> feed, unsigned int pos
 		rsscache->internalize_rssfeed(feed, ignore_disp ? &ign : NULL);
 		LOG(LOG_DEBUG, "controller::save_feed: after internalize_rssfeed");
 		feed->set_tags(urlcfg->get_tags(feed->rssurl()));
-		{
-			unsigned int order = feeds[pos]->get_order();
-			scope_mutex itemlock(&feeds[pos]->item_mutex);
-			feeds[pos]->clear_items();
-			feed->set_order(order);
-		}
+		feed->set_order(feeds[pos]->get_order());
 		feeds[pos] = feed;
 		v->notify_itemlist_change(feeds[pos]);
 	} else {
