@@ -85,6 +85,7 @@ void feedlist_formaction::process_operation(operation op, bool automatic, std::v
 	std::istringstream posname(feedpos);
 	unsigned int pos = 0;
 	posname >> pos;
+REDO:
 	switch (op) {
 		case OP_OPEN: {
 				if (f->get_focus() == "feeds") {
@@ -117,35 +118,41 @@ void feedlist_formaction::process_operation(operation op, bool automatic, std::v
 			v->get_ctrl()->reload_urls_file();
 			break;
 		case OP_SORT: {
-				char c = v->confirm(_("Sort by (f)irsttag/(t)itle/(a)rticlecount/(u)nreadarticlecount/(n)one?"), _("ftaun"));
+				/// This string is related to the letters in parentheses in the
+				/// "Sort by (f)irsttag/..." and "Reverse Sort by (f)irsttag/..." messages
+				std::string input_options = _("ftaun");
+				char c = v->confirm(_("Sort by (f)irsttag/(t)itle/(a)rticlecount/(u)nreadarticlecount/(n)one?"), input_options);
 				if (!c) break;
-				std::string result(1, c);
-				if (result == _("f")) {
+				unsigned int n_options = ((std::string) "ftaun").length();
+				if (input_options.length() < n_options) break;
+				if (c == input_options.at(0)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "firsttag-desc");
-				} else if (result == _("t")) {
+				} else if (c == input_options.at(1)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "title-desc");
-				} else if (result == _("a")) {
+				} else if (c == input_options.at(2)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "articlecount-desc");
-				} else if (result == _("u")) {
+				} else if (c == input_options.at(3)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "unreadarticlecount-desc");
-				} else if (result == _("n")) {
+				} else if (c == input_options.at(4)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "none-desc");
 				}
 			}
 			break;
 		case OP_REVSORT: {
-				char c = v->confirm(_("Reverse Sort by (f)irsttag/(t)itle/(a)rticlecount/(u)nreadarticlecount/(n)one?"), _("ftaun"));
+				std::string input_options = _("ftaun");
+				char c = v->confirm(_("Reverse Sort by (f)irsttag/(t)itle/(a)rticlecount/(u)nreadarticlecount/(n)one?"), input_options);
 				if (!c) break;
-				std::string result(1, c);
-				if (result == _("f")) {
+				unsigned int n_options = ((std::string) "ftaun").length();
+				if (input_options.length() < n_options) break;
+				if (c == input_options.at(0)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "firsttag-asc");
-				} else if (result == _("t")) {
+				} else if (c == input_options.at(1)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "title-asc");
-				} else if (result == _("a")) {
+				} else if (c == input_options.at(2)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "articlecount-asc");
-				} else if (result == _("u")) {
+				} else if (c == input_options.at(3)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "unreadarticlecount-asc");
-				} else if (result == _("n")) {
+				} else if (c == input_options.at(4)) {
 					v->get_cfg()->set_configvalue("feed-sort-order", "none-asc");
 				}
 			}
@@ -333,6 +340,10 @@ void feedlist_formaction::process_operation(operation op, bool automatic, std::v
 			v->get_ctrl()->edit_urls_file();
 			break;
 		case OP_QUIT:
+			if (tag != "") {
+				op = OP_CLEARTAG;
+				goto REDO;
+			}
 			LOG(LOG_INFO, "feedlist_formaction: quitting");
 			if (automatic || !v->get_cfg()->get_configvalue_as_bool("confirm-exit") || v->confirm(_("Do you really want to quit (y:Yes n:No)? "), _("yn")) == *_("y")) {
 				quit = true;
