@@ -46,13 +46,14 @@ static op_desc opdescs[] = {
 	{ OP_SEARCH,			"open-search",				"/",	_("Open search dialog"),				KM_FEEDLIST | KM_HELP | KM_ARTICLELIST | KM_ARTICLE },
 	{ OP_GOTO_URL,			"goto-url",				"#",	_("Goto URL #"),				KM_ARTICLE },
 	{ OP_ENQUEUE,			"enqueue",					"e",	_("Add download to queue"),				KM_ARTICLE },
-	{ OP_RELOADURLS,		"reload-urls",				"^R",	_("Reload the list of URLs from the configuration"),	KM_ARTICLELIST },
+	{ OP_RELOADURLS,		"reload-urls",				"^R",	_("Reload the list of URLs from the configuration"),	KM_FEEDLIST },
 	{ OP_PB_DOWNLOAD,		"pb-download",				"d",	_("Download file"),						KM_PODBEUTER },
 	{ OP_PB_CANCEL,			"pb-cancel",				"c",	_("Cancel download"),					KM_PODBEUTER },
 	{ OP_PB_DELETE,			"pb-delete",				"D",	_("Mark download as deleted"),			KM_PODBEUTER },
 	{ OP_PB_PURGE,			"pb-purge",					"P",	_("Purge finished and deleted downloads from queue"),	KM_PODBEUTER },
 	{ OP_PB_TOGGLE_DLALL,	"pb-toggle-download-all",	"a",	_("Toggle automatic download on/off"),	KM_PODBEUTER },
 	{ OP_PB_PLAY,			"pb-play",					"p",	_("Start player with currently selected download"),		KM_PODBEUTER },
+	{ OP_PB_MARK_FINISHED,  "pb-mark-as-finished",          "m",    _("Mark file as finished (not played)"), KM_PODBEUTER },
 	{ OP_PB_MOREDL,			"pb-increase-max-dls",		"+",	_("Increase the number of concurrent downloads"),		KM_PODBEUTER },
 	{ OP_PB_LESSDL,			"pb-decreate-max-dls",		"-",	_("Decrease the number of concurrent downloads"),		KM_PODBEUTER },
 	{ OP_REDRAW,			"redraw",					"^L",	_("Redraw screen"),						KM_SYSKEYS },
@@ -240,7 +241,7 @@ operation keymap::get_operation(const std::string& keycode, const std::string& c
 void keymap::dump_config(std::vector<std::string>& config_output) {
 	for (unsigned int i=1;contexts[i]!=NULL;i++) { // TODO: optimize
 		std::map<std::string,operation>& x = keymap_[contexts[i]];
-		for (std::map<std::string,operation>::iterator it = x.begin();it!=x.end();it++) {
+		for (std::map<std::string,operation>::iterator it = x.begin();it!=x.end();++it) {
 			if (it->second < OP_INT_MIN) {
 				std::string configline = "bind-key ";
 				configline.append(it->first);
@@ -252,14 +253,14 @@ void keymap::dump_config(std::vector<std::string>& config_output) {
 			}
 		}
 	}
-	for (std::map<std::string,std::vector<macrocmd> >::iterator it=macros_.begin();it!=macros_.end();it++) {
+	for (std::map<std::string,std::vector<macrocmd> >::iterator it=macros_.begin();it!=macros_.end();++it) {
 		std::string configline = "macro ";
 		configline.append(it->first);
 		configline.append(" ");
 		unsigned int i=0;
-		for (std::vector<macrocmd>::iterator jt=it->second.begin();jt!=it->second.end();jt++,i++) {
+		for (std::vector<macrocmd>::iterator jt=it->second.begin();jt!=it->second.end();++jt,i++) {
 			configline.append(getopname(jt->op));
-			for (std::vector<std::string>::iterator kt=jt->args.begin();kt!=jt->args.end();kt++) {
+			for (std::vector<std::string>::iterator kt=jt->args.begin();kt!=jt->args.end();++kt) {
 				configline.append(" ");
 				configline.append(utils::quote(*kt));
 			}
@@ -312,7 +313,7 @@ void keymap::handle_action(const std::string& action, const std::vector<std::str
 		macrocmd tmpcmd;
 		tmpcmd.op = OP_NIL;
 		bool first = true;
-		it++;
+		++it;
 
 		while (it != params.end()) {
 			if (first && *it != ";") {
